package com.ruoyi.bst.agreement.mapper;

import java.util.List;
import com.ruoyi.bst.agreement.domain.Agreement;
import com.ruoyi.bst.agreement.domain.AgreementVO;
import com.ruoyi.bst.agreement.domain.AgreementQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 协议列表Mapper接口
 *
 * @author ruoyi
 * @date 2025-05-14
 */
public interface AgreementMapper
{
    /**
     * 查询协议列表
     *
     * @param id 协议列表主键
     * @return 协议列表
     */
    AgreementVO selectAgreementById(Long id);

    /**
     * 查询协议列表列表
     *
     * @param query 协议列表
     * @return 协议列表集合
     */
    List<AgreementVO> selectAgreementList(@Param("query")AgreementQuery query);

    /**
     * 新增协议列表
     *
     * @param agreement 协议列表
     * @return 结果
     */
    int insertAgreement(Agreement agreement);

    /**
     * 批量新增协议列表
     */
    int batchInsert(@Param("list") List<? extends Agreement> list);

    /**
     * 批量修改协议列表
     */
    int batchUpdate(@Param("list") List<? extends Agreement> list);

    /**
     * 修改协议列表
     *
     * @param agreement 协议列表
     * @return 结果
     */
    public int updateAgreement(@Param("data") Agreement agreement);

    /**
     * 删除协议列表
     *
     * @param id 协议列表主键
     * @return 结果
     */
    int deleteAgreementById(Long id);

    /**
     * 批量删除协议列表
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAgreementByIds(Long[] ids);
}
